function [t,xt] = lorenz3v(x_0,tmax)
 % [t,xt] = lorenz3v(x0,tmax)
 % The evolution of the Lorenz 1963 3-variable model
 % Inputs:  - x_0, a vector of initial positions
 %          - tmax, the maximum time
 % Outputs: - t, the time array
 %          - xt, the nature run
 
 % the time array, 8 steps are linear windows, 25 steps are nonlinear windows
 tstep = 0.01;
 t = (0:tstep:tmax)';    

 % the vectors for space vars
 % they're organized in a matrix of 3 columns [x,y,z]
 xt = zeros(length(t),3);
 xt(1,:) = x_0;

 for i = 1:length(t)-1 %for each time
  Varsold = xt(i,:);
  % we integrate using RK4
  Varsnew = rk4(Varsold,tstep);
  xt(i+1,:)= Varsnew;
  %i
 end
end


%% Auxiliary functions
function Varsnew = rk4(Varsold,tstep)
 % each k has size [3 x J]
 k1 = f(Varsold);
 k2 = f(Varsold+1/2.*tstep.*k1);
 k3 = f(Varsold+1/2.*tstep.*k2);
 k4 = f(Varsold+tstep.*k3);
 Varsnew = Varsold + 1/6*tstep*(k1+2*k2+2*k3+k4);
end

function k = f(x)
 % the parameters
 sigma = 10;     b = 8/3;    r = 28;
 % initialize 
 k = NaN(size(x));
 % the Lorenz equations
 k(1,1) = sigma*(x(1,2)-x(1,1));
 k(1,2) = (x(1,1)*(r-x(1,3))-x(1,2));
 k(1,3) = x(1,1)*x(1,2)-b*x(1,3);
end
 




